==> haskell-type-errors-0.2.0.2-83-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-type-errors.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 type-errors
version:              0.2.0.2
visibility:           public
id:                   type-errors-0.2.0.2-9ajYn76U2vl70NckQtrpnd
key:                  type-errors-0.2.0.2-9ajYn76U2vl70NckQtrpnd
license:              BSD-3-Clause
copyright:            2019 Sandy Maguire
maintainer:           sandy@sandymaguire.me
author:               Sandy Maguire
homepage:             https://github.com/isovector/type-errors#readme
synopsis:             Tools for writing better type errors
description:
    Please see the README on GitHub at <https://github.com/isovector/type-errors#readme>

category:             Type
abi:                  9f10a8972da17a1708fe8c7dd7f10c69
exposed:              True
exposed-modules:      Type.Errors
hidden-modules:       Paths_type_errors
import-dirs:          /usr/lib/ghc-9.4.8/site-local/type-errors-0.2.0.2
library-dirs:         /usr/lib/ghc-9.4.8/site-local/type-errors-0.2.0.2
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/type-errors-0.2.0.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-type-errors
hs-libraries:         HStype-errors-0.2.0.2-9ajYn76U2vl70NckQtrpnd
depends:
    base-4.17.2.1 first-class-families-0.8.1.0-GHDQ6gIu3MO757TPVLJ5eT
    syb-0.7.2.4-BSKNIdKaKEZCAuXcVMqAaV template-haskell-2.19.0.0
    th-abstraction-0.5.0.0-BROQwjXmGCt8uLmQUfLqOy

haddock-interfaces:   /usr/share/doc/haskell-type-errors/html/type-errors.haddock
haddock-html:         /usr/share/doc/haskell-type-errors/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-type-errors-0.2.0.2-84-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-type-errors.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 type-errors
version:              0.2.0.2
visibility:           public
id:                   type-errors-0.2.0.2-KZglDEiYyT9GHkqcbxI46d
key:                  type-errors-0.2.0.2-KZglDEiYyT9GHkqcbxI46d
license:              BSD-3-Clause
copyright:            2019 Sandy Maguire
maintainer:           sandy@sandymaguire.me
author:               Sandy Maguire
homepage:             https://github.com/isovector/type-errors#readme
synopsis:             Tools for writing better type errors
description:
    Please see the README on GitHub at <https://github.com/isovector/type-errors#readme>

category:             Type
abi:                  dc63c78bf6397f6ca3cf845c7c6bf20c
exposed:              True
exposed-modules:      Type.Errors
hidden-modules:       Paths_type_errors
import-dirs:          /usr/lib/ghc-9.4.8/site-local/type-errors-0.2.0.2
library-dirs:         /usr/lib/ghc-9.4.8/site-local/type-errors-0.2.0.2
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/type-errors-0.2.0.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-type-errors
hs-libraries:         HStype-errors-0.2.0.2-KZglDEiYyT9GHkqcbxI46d
depends:
    base-4.17.2.1 first-class-families-0.8.1.0-GHDQ6gIu3MO757TPVLJ5eT
    syb-0.7.2.4-5o1aA7VmoIW8wlDGJbJzgh template-haskell-2.19.0.0
    th-abstraction-0.5.0.0-BROQwjXmGCt8uLmQUfLqOy

haddock-interfaces:   /usr/share/doc/haskell-type-errors/html/type-errors.haddock
haddock-html:         /usr/share/doc/haskell-type-errors/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
